# Jupyter Notebooks

A full set of jupyter notebooks with several examples 
of how to use NIDAQ and Arduino for data acquisition, 
send data and other experiments can be found on [Github repository](https://github.com/samirmartins/pydaq/tree/main/examples).